@@ -2,13 +2,11 @@
  *  File:             boxes.c
  *  Date created:     March 18, 1999 (Thursday, 15:09h)
  *  Author:           Copyright (C) 1999 Thomas Jensen <boxes@thomasjensen.com>
- *  Version:          $Id: boxes.c,v 1.39 2006/08/28 15:53:46 tsjensen Exp $
  *  Language:         ANSI C
- *  Platforms:        sunos5/sparc, for now
- *  World Wide Web:   http://boxes.thomasjensen.com/
+ *  Web Site:         http://boxes.thomasjensen.com/
  *  Purpose:          Filter to draw boxes around input text (and remove it).
  *
- *  Remarks: o This program is free software; you can redistribute it
+ *  License: o This program is free software; you can redistribute it
  *             and/or modify it under the terms of the GNU General Public
  *             License as published by the Free Software Foundation; either
  *             version 2 of the License, or (at your option) any later
@@ -41,191 +39,6 @@
  *             And again, changing this would pretty much mean a total
  *             rewrite.
  *
- *  Revision History:
- *
- *    $Log: boxes.c,v $
- *    Revision 1.39  2006/08/28 15:53:46  tsjensen
- *    Added support for --help and -? options, which do the same as -h
- *    (This feature was requested by Raphael Wimmer).
- *
- *    Revision 1.38  2006/07/22 19:40:40  tsjensen
- *    Applied patch by Christoph Dreyer to support unexpansion of leading tabs
- *    Added ability to retain leading tabs in their original positions
- *    Mending a box with -m now implies -k false
- *
- *    Revision 1.37  2006/07/12 05:49:50  tsjensen
- *    Updated email and web addresses in comment header etc.
- *    Applied patch by Elmar Loos that adds -m option for mending a box
- *    Changed a few more things to make the box mending patch work in
- *    connection with all the other boxes options
- *
- *    Revision 1.36  2000-04-01 10:27:17-08  tsjensen
- *    Added -c option (simple comment definition)
- *
- *    Revision 1.35  2000/03/21 14:26:31  tsjensen
- *    Minor change to make boxes compile on DEC/OSF, too (S_ISDIR)
- *
- *    Revision 1.34  2000/03/17 23:44:26  tsjensen
- *    Port to Win32 platform based on patches by Ron Aaron
- *    Changes only affect Win32 version. Win32 behavior differs from the UNIX
- *    platforms in the way the config file is searched and the config file
- *    name (boxes.cfg).
- *
- *    Revision 1.33  1999/09/10 19:21:05  tsjensen
- *    Eliminated use of PATH_MAX in order to ease porting
- *    Restructured infile/outfile code to eliminate need for access() function
- *    and improve readability
- *    Added file type check before reading config file. boxes used to generate
- *    a weird error message if the config file is a directory
- *
- *    Revision 1.32  1999/08/22 11:34:46  tsjensen
- *    Bugfix: no-input-check must take place before indentation computation
- *
- *    Revision 1.31  1999/08/21 23:33:03  tsjensen
- *    Added usage of system-wide config file (GLOBALCONF from boxes.h)
- *    Moved config file selection code into it own function (get_config_file())
- *
- *    Revision 1.30  1999/08/21 15:55:42  tsjensen
- *    Updated usage information
- *    Updated quickinfo (-l -d) with killblank default value
- *    Made indentation computation into a function of its own (get_indent())
- *    Bugfix: REVERSION code may change indentation -> recompute if necessary
- *
- *    Revision 1.29  1999/08/16 18:29:39  tsjensen
- *    Added output of total number of designs for -l
- *
- *    Revision 1.28  1999/07/23 16:15:48  tsjensen
- *    Added quickinfo mode to list_styles(). Called with -l and -d together.
- *
- *    Revision 1.27  1999/07/21 16:53:17  tsjensen
- *    Bugfix: Empty box sides were still counted when -s was specified (so
- *    -s x5 would get you only three lines).
- *
- *    Revision 1.26  1999/07/20 18:45:29  tsjensen
- *    Added GNU GPL disclaimer
- *    Added -k option (kill leading/trailing blank lines on removal yes/no)
- *    Bugfix: REPLACE and indentation conflict. Now applying regexp substitutions
- *    only after indentation was already handled.
- *
- *    Revision 1.25  1999/07/12 18:16:36  tsjensen
- *    Added include "config.h" to top of file
- *
- *    Revision 1.24  1999/06/30 12:37:25  tsjensen
- *    Added [lcr] "shorthand" to -a option
- *
- *    Revision 1.23  1999/06/30 12:16:38  tsjensen
- *    Removed entire select_design stuff, because the parser now returns much
- *    smaller data structures. The first design pointed to by designs is always
- *    the one we need (except for ops on *all* designs).
- *    The first design in config file is now default design (no DEF_DESIGN anymore).
- *
- *    Revision 1.22  1999/06/28 12:19:29  tsjensen
- *    Moved parser init and cleanup from main() to parser.y
- *    Some further cleanup in main()
- *
- *    Revision 1.21  1999/06/25 18:46:39  tsjensen
- *    Bugfix: Mixed up SW and NE in padding calculation (tricky, that one)
- *    Added indent mode command line option for grammar overrides
- *    Moved empty_side() to shape.c after small change in signature
- *    Added text-in-block justification (j) to alignment option (-a)
- *
- *    Revision 1.20  1999/06/23 19:17:27  tsjensen
- *    Removed snprintf() and vsnprintf() prototypes (why were they in anyway?)
- *    along with stdarg.h include
- *    Exported input global data and empty_side() function
- *    Declared non-exported functions static
- *    Moved horiz_precalc(), vert_precalc(), horiz_assemble(), vert_assemble(),
- *    horiz_generate(), vert_generate(), generate_box() and output_box() to a
- *    new file generate.c
- *    Moved best_match(), hmm(), detect_horiz(), detect_design(), remove_box()
- *    and output_input() to a new file remove.c
- *
- *    Revision 1.19  1999/06/23 12:31:26  tsjensen
- *    Improvements on design detection (could still be better though)
- *    Moved iscorner(), on_side(), isempty(), shapecmp(), both_on_side(),
- *    shape_distance(), empty_side(), highest(), and widest() as well as
- *    some data structures and macros related to shapes to new file shape.c
- *
- *    Revision 1.18  1999/06/22 12:03:33  tsjensen
- *    DEBUGging is now activated in boxes.h
- *    Moved MAX_TABSTOP, LINE_MAX macros and struct opt_t to boxes.h
- *    Moved BMAX, strrstr(), btrim(), yyerror(), expand_tabs_into(),
- *    regerror(), empty_line() to a new file tools.c, added #include tools.h
- *    Some cleanup in main()
- *    Declared style_sort() helper function static
- *    Renamed strrstr() to my_strnrstr() (now defined in tools.c)
- *    Default design is now defined by DEF_DESIGN macro
- *    Changed select_design(), because default design value now set in process_commandline()
- *    Bugfix: segfaulted if shape was bigger than input when detecting design
- *    Bugfix: Padding was not removed when box was removed
- *    Bugfix: Forgot null byte when removing west box side
- *
- *    Revision 1.17  1999/06/20 14:20:29  tsjensen
- *    Added code for padding handling (-p)
- *    Added BMAX macro (returns maximum of two values)
- *
- *    Revision 1.16  1999/06/17 19:07:06  tsjensen
- *    Moved line_t to boxes.h
- *    empty_line() now also considers \r and \n whitespace
- *    Added empty_side() function
- *    Added handling of empty box sides in output_box()
- *
- *    Revision 1.15  1999/06/15 12:07:39  tsjensen
- *    Removed a stray debug message
- *    Move apply_substitutions() regexp handling function up in file
- *    Use apply_substitutions() in read_input() routine also
- *    Moved "extern int yyparse()" prototype to start of file
- *
- *    Revision 1.14  1999/06/14 12:08:49  tsjensen
- *    Bugfix: best_match() box side detection used numw instead of nume
- *    Added apply_substitutions() routine for central regexp handling
- *    Added regexp reversion code for box removal
- *    Unified use of current_re[pv]rule
- *    Added a few comments and debugging code
- *
- *    Revision 1.13  1999/06/13 15:28:31  tsjensen
- *    Some error message clean-up
- *    Regular expression substitutions on input text only if *drawing* a box,
- *    not if the box is to be removed (requires other substitutions, todo).
- *    Added code for box design auto-detection when removing a box.
- *
- *    Revision 1.12  1999/06/04 18:13:26  tsjensen
- *    Don't adjust indentation after removing a box unless something was
- *    removed on the west side
- *    East Padding made dynamic, i.e. dependant on the east side size
- *
- *    Revision 1.11  1999/06/03 19:24:14  tsjensen
- *    A few fixes related to box removal (as expected)
- *
- *    Revision 1.10  1999/06/03 18:54:05  tsjensen
- *    Lots of fixes
- *    Added remove box functionality (-r), which remains to be tested
- *
- *    Revision 1.9  1999/04/09 13:33:24  tsjensen
- *    Removed code related to OFFSET blocks (obsolete)
- *
- *    Revision 1.8  1999/04/04 16:09:01  tsjensen
- *    Added code for specification of indentation handling of input
- *    Added regular expression substitutions
- *    Some minor fixes
- *
- *    Revision 1.7  1999/04/02 18:42:44  tsjensen
- *    Added infile/outfile parameter code (pasted from tal, more or less)
- *    Added code to remove trailing spaces from output lines
- *
- *    Revision 1.6  1999/04/01 17:26:18  tsjensen
- *    Some bug fixes
- *    Added size option (-s)
- *    Added Alignment Option (-a)
- *    It seems actually usable for drawing boxes :-)
- *
- *    Revision 1.4  1999/03/30 13:30:19  tsjensen
- *    Added minimum width/height for a design. Fixed screwed tiny boxes.
- *    Bugfix: Did not handle zero input.
- *
- *    Revision 1.1  1999/03/18 15:09:17  tsjensen
- *    Initial revision
- *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  */
 
@@ -1279,7 +1092,7 @@ static int list_styles()
                         fprintf (opt.outfile, "%s: ", shape_name[i]);
                     else {
                         space[strlen(shape_name[i])+2] = '\0';
-                        fprintf (opt.outfile, space);
+                        fprintf (opt.outfile, "%s", space);
                         space[strlen(shape_name[i])+2] = ' ';
                     }
                     if (j < d->shape[i].height) {
@@ -1287,7 +1100,7 @@ static int list_styles()
                     }
                     else {
                         space[d->shape[i].width+2] = '\0';
-                        fprintf (opt.outfile, space);
+                        fprintf (opt.outfile, "%s", space);
                         space[d->shape[i].width+2] = ' ';
                     }
                 }
